/**
 ********************************************************************
 * @file    osdk_policy.h
 * @version V1.0.0
 * @date    2019/09/15
 * @brief   Define the osdk policy binary array
 *
 * @copyright (c) 2018-2019 DJI. All rights reserved.
 *
 * All information contained herein is, and remains, the property of DJI.
 * The intellectual and technical concepts contained herein are proprietary
 * to DJI and may be covered by U.S. and foreign patents, patents in process,
 * and protected by trade secret or copyright law.  Dissemination of this
 * information, including but not limited to data and other proprietary
 * material(s) incorporated within the information, in any form, is strictly
 * prohibited without the express written consent of DJI.
 *
 * If you receive this source code without DJI’s authorization, you may not
 * further disseminate the information, and you must immediately remove the
 * source code and notify DJI of its removal. DJI reserves the right to pursue
 * legal actions against you for any loss(es) or damage(s) caused by your
 * failure to do so.
 *
 *********************************************************************
 */


#ifndef _OSDK_POLICY_H_
#define _OSDK_POLICY_H_

#include <stdint.h>

#define OSDK_IDENTITY_VERIFY_CALMD5_MAX_NUM          (33 + 17)
#define OSDK_POLICY_FILE_VERSION_OFFSET              (256)
/*!
 * OSDK Policy
 * Creator  : DJI
 * Date     : 2020-05-07
 * OSDK Ver : OSDK 4.0
 * */

static const uint8_t s_osdkPolicyFileBinaryArray[] = {
  0x25, 0xBC, 0x8D, 0x94, 0xE3, 0x34, 0xDB, 0x99, 0x5A, 0x53, 0x30, 0xA4, 0xDA,
  0x0A, 0x15, 0xD0, 0xA0, 0x77, 0xE4, 0x98, 0xB0, 0x80, 0x4C, 0x6E, 0xD3, 0x82,
  0xB4, 0x70, 0x26, 0xE3, 0x15, 0x21, 0x4F, 0x8B, 0x63, 0x89, 0x68, 0x1F, 0x11,
  0xDB, 0x0B, 0x2F, 0x3B, 0x89, 0x29, 0xAF, 0xB8, 0x48, 0x58, 0x99, 0x83, 0xF9,
  0xDF, 0x60, 0x26, 0x60, 0xA0, 0xE9, 0x23, 0x96, 0x22, 0x6A, 0xE5, 0x8D, 0xCD,
  0x2F, 0xE7, 0x51, 0x71, 0x8D, 0x4E, 0x4F, 0xA2, 0x9E, 0xA4, 0xE1, 0x5C, 0x31,
  0xA2, 0x61, 0xED, 0x72, 0x12, 0x4A, 0x8E, 0x64, 0xC3, 0xA3, 0x34, 0x67, 0x2E,
  0x90, 0xB8, 0xCB, 0x36, 0xFD, 0x58, 0x9D, 0x93, 0x2C, 0x5B, 0x82, 0x19, 0xE2,
  0xC3, 0x8F, 0xBE, 0x13, 0x52, 0x61, 0x87, 0x38, 0xA4, 0x1D, 0x4C, 0x33, 0x1F,
  0xB4, 0x8E, 0x82, 0x12, 0x85, 0x9A, 0xB6, 0x12, 0xB3, 0xD6, 0x22, 0xA0, 0xB1,
  0x22, 0xEE, 0xEC, 0x28, 0x85, 0xFB, 0x3F, 0x3B, 0x2C, 0x64, 0x88, 0xE0, 0xEC,
  0xE3, 0xB2, 0x60, 0x84, 0xB6, 0x9F, 0x0D, 0x1A, 0xA2, 0x09, 0xF3, 0x37, 0xC5,
  0x45, 0xBA, 0x93, 0x69, 0x34, 0x20, 0x39, 0x4A, 0xEA, 0x91, 0x3A, 0xB4, 0x7F,
  0xF0, 0x7D, 0xFA, 0xB4, 0x6E, 0x5C, 0x15, 0x34, 0xFC, 0xC3, 0x22, 0x0B, 0xE8,
  0x02, 0x68, 0xB2, 0x1E, 0x30, 0xB8, 0xC2, 0x7A, 0x56, 0x45, 0x8C, 0x33, 0xC5,
  0x1C, 0x8F, 0x9A, 0x89, 0xE7, 0xCB, 0x7A, 0xE0, 0x86, 0x82, 0x88, 0x06, 0x6C,
  0xC6, 0xE2, 0x62, 0xFA, 0x7A, 0xFB, 0x11, 0xAD, 0x80, 0x32, 0xB2, 0xCF, 0xD9,
  0xF0, 0xD8, 0xA3, 0x11, 0x5D, 0x8F, 0x28, 0x10, 0xB9, 0x49, 0x1A, 0x04, 0xC1,
  0x01, 0x4B, 0xD0, 0x19, 0xF1, 0xAC, 0xA0, 0x0E, 0x9C, 0xD2, 0x42, 0x5F, 0x1D,
  0x89, 0x2E, 0x23, 0xEB, 0xBC, 0x88, 0xCA, 0x98, 0x41, 0x00, 0x00, 0x6D, 0x00,
  0x01, 0x00, 0x69, 0x00, 0x01, 0x00, 0x02, 0x00, 0xFF, 0xFF, 0x00, 0x00, 0x04,
  0x00, 0x00, 0x05, 0x26, 0x27, 0x02, 0x07, 0x12, 0x00, 0x01, 0x02, 0x10, 0x11,
  0x1E, 0x1F, 0x22, 0x2B, 0x2E, 0x2F, 0x30, 0x31, 0x34, 0x35, 0x6A, 0x6B, 0xC4,
  0xC6, 0x09, 0xB8, 0x80, 0x4A, 0xE1, 0xEB, 0xEC, 0x03, 0x01, 0x00, 0x00, 0x1B,
  0x04, 0x02, 0x00, 0x00, 0x0A, 0x4C, 0x05, 0x01, 0x00, 0x00, 0x0B, 0x08, 0x01,
  0x02, 0x00, 0x67, 0x68, 0x65, 0x0B, 0x01, 0x00, 0x00, 0x04, 0x21, 0x00, 0x02,
  0x00, 0x05, 0x06, 0x22, 0x01, 0x04, 0x00, 0x01, 0x0E, 0x17, 0x1E, 0x27, 0x24,
  0x01, 0x02, 0x00, 0x11, 0x12, 0x32, 0x3C, 0x02, 0x00, 0x00, 0x37, 0x40, 0x49,
  0x02, 0x00, 0x00, 0x20, 0x30
};

#endif    /* _OSDK_POLICY_H_ */
